@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.024_02';
+our $VERSION = '0.026_01';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -143,6 +143,8 @@ __PACKAGE__->add_property( 'alien_arch' => defined $ENV{ALIEN_ARCH} ? $ENV{ALIEN
 
 __PACKAGE__->add_property( 'alien_helper' => {} );
 
+__PACKAGE__->add_property( 'alien_env' => {} );
+
 ################
 #  ConfigData  #
 ################
@@ -700,7 +702,8 @@ sub alien_do_system {
   my $self = shift;
   my $command = shift;
   
-  local $ENV{PATH} = $ENV{PATH};
+  local %ENV = %ENV;
+  $ENV{PATH} = $ENV{PATH};
   
   if ($self->config_data( 'msys' )) {
     $self->alien_bin_requires->{'Alien::MSYS'} ||= 0
@@ -734,8 +737,6 @@ sub alien_do_system {
     $config->prepend_path( PATH => sort keys %path );
   }
 
-  local $ENV{CONFIG_SITE} = $ENV{CONFIG_SITE};
-  
   # If we are using autoconf, then create a site.config file
   # that specifies the same compiler and compiler linker flags
   # as were used for building Perl.  This is helpful for
@@ -766,6 +767,14 @@ sub alien_do_system {
     $config->set( CONFIG_SITE => $config_site );
     $ENV{CONFIG_SITE} = $config_site;
   }
+  
+  foreach my $key (sort keys %{ $self->alien_env })
+  {
+    my $value = $self->alien_interpolate($self->alien_env->{$key});
+    defined $value ? $ENV{$key} = $value : delete $ENV{$key};
+    $config ||= _shell_config_generate();
+    $config->set( $key => $value );
+  }
 
   if($config) {  
     if($^O eq 'MSWin32') {
@@ -889,6 +898,8 @@ sub alien_interpolate {
   #   current interpreter ($^X) (ph: %x)
   my $perl = $self->perl;
   $string =~ s/(?<!\%)\%x/$perl/g;
+  $perl =~ s{\\}{/}g if $^O eq 'MSWin32';
+  $string =~ s/(?<!\%)\%X/$perl/g;
 
   # Version, but only if needed.  Complain if needed and not yet
   # stored.
